"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentCheckpointManager = void 0;
class DocumentCheckpointManager {
    constructor() {
        this.checkpointInfo = {
            lastCheckpointTime: Date.now(),
            rawMessagesSinceCheckpoint: 0,
        };
        this.noActiveClients = false;
    }
    updateCheckpointMessages(message) {
        // updates checkpoint message
        this.checkpointInfo.currentCheckpointMessage = message;
        if (this.noActiveClients) {
            this.checkpointInfo.nextKafkaCheckpointMessage = undefined;
            this.checkpointInfo.currentKafkaCheckpointMessage = message;
        }
        else {
            // Keeps Kafka checkpoint behind by 1 message
            const kafkaCheckpointMessage = this.checkpointInfo.nextKafkaCheckpointMessage;
            this.checkpointInfo.nextKafkaCheckpointMessage = message;
            this.checkpointInfo.currentKafkaCheckpointMessage = kafkaCheckpointMessage;
        }
    }
    clearCheckpointIdleTimer() {
        if (this.checkpointInfo.idleTimer !== undefined) {
            clearTimeout(this.checkpointInfo.idleTimer);
            this.checkpointInfo.idleTimer = undefined;
        }
    }
    resetCheckpointTimer() {
        this.clearCheckpointIdleTimer();
        this.checkpointInfo.lastCheckpointTime = Date.now();
        this.checkpointInfo.rawMessagesSinceCheckpoint = 0;
    }
    updateCheckpointIdleTimer(timeout, idleTimeCheckpoint, isDocumentCorrupt = false) {
        this.clearCheckpointIdleTimer();
        const initalCheckpointMessage = this.checkpointInfo.currentCheckpointMessage;
        this.checkpointInfo.idleTimer = setTimeout(() => {
            this.checkpointInfo.idleTimer = undefined;
            // verify that the current message matches the message that started this timer
            // original implementation from Deli
            if (initalCheckpointMessage === this.checkpointInfo.currentCheckpointMessage &&
                !isDocumentCorrupt) {
                this.resetCheckpointTimer();
                if (initalCheckpointMessage) {
                    idleTimeCheckpoint(initalCheckpointMessage);
                }
            }
        }, timeout);
    }
    incrementRawMessageCounter() {
        this.checkpointInfo.rawMessagesSinceCheckpoint++;
    }
    resetRawMessageCounter() {
        this.checkpointInfo.rawMessagesSinceCheckpoint = 0;
    }
    getNoActiveClients() {
        return this.noActiveClients;
    }
    setNoActiveClients(noActiveClients) {
        this.noActiveClients = noActiveClients;
    }
    getCheckpointInfo() {
        return this.checkpointInfo;
    }
    setLastCheckpointTime(timestamp) {
        this.checkpointInfo.lastCheckpointTime = timestamp;
    }
    getLastCheckpointTime() {
        return this.checkpointInfo.lastCheckpointTime;
    }
}
exports.DocumentCheckpointManager = DocumentCheckpointManager;
//# sourceMappingURL=documentLambdaCheckpointManager.js.map