"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.NoOpLambda = void 0;
/**
 * @internal
 */
class NoOpLambda {
    constructor(context, checkpointConfiguration) {
        this.context = context;
        this.checkpointConfiguration = checkpointConfiguration;
        this.opsCount = 0;
        this.lastCheckpointOffset = 0;
        this.idleTimer = undefined;
        this.maxTimer = undefined;
    }
    handler(message) {
        // default
        if (!this.checkpointConfiguration?.enabled) {
            this.context.checkpoint(message);
            return undefined;
        }
        this.currentMessage = message;
        this.opsCount++;
        if (this.opsCount >= this.checkpointConfiguration.maxMessages) {
            this.configurableCheckpoint(this.currentMessage);
        }
        if (!this.maxTimer) {
            this.resetMaxTimer();
        }
        if (this.checkpointConfiguration?.enabled) {
            this.resetIdleTimer();
        }
        return undefined;
    }
    close() { }
    configurableCheckpoint(message) {
        if (message?.offset > this.lastCheckpointOffset) {
            this.context.checkpoint(message);
            if (this.idleTimer) {
                clearTimeout(this.idleTimer);
                this.idleTimer = undefined;
            }
            if (this.maxTimer) {
                clearTimeout(this.maxTimer);
                this.maxTimer = undefined;
            }
            this.opsCount = 0;
            this.lastCheckpointOffset = message.offset;
        }
    }
    resetMaxTimer() {
        console.log(`Resetting max timer`);
        this.maxTimer = setInterval(() => {
            console.log(`MaxTime checkpoint`);
            this.configurableCheckpoint(this.currentMessage);
        }, this.checkpointConfiguration?.maxTime);
    }
    resetIdleTimer() {
        if (this.idleTimer) {
            clearTimeout(this.idleTimer);
        }
        this.idleTimer = setInterval(() => {
            this.configurableCheckpoint(this.currentMessage);
        }, this.checkpointConfiguration?.idleTime);
    }
}
exports.NoOpLambda = NoOpLambda;
//# sourceMappingURL=noOpLambda.js.map